#! /bin/make

#
# @description: Example applications for Impact Acquire
# @copyright: Copyright (C) 2008 - 2021 Balluff GmbH
# @authors: APIs and drivers development team at Balluff GmbH
# @initial date: 2008-08-12
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice (including the next paragraph) shall be included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

##############################################
# Makefile for 'IPConfigure'
##############################################
#-------------------------------------------
DEST:=$(shell basename `pwd`)

#-------------------------------------------
ifndef MVIMPACT_ACQUIRE_SOURCE_DIR
	ifndef MVIMPACT_ACQUIRE_DIR
		ROOT_PATH=../..
	else
		ROOT_PATH=$(MVIMPACT_ACQUIRE_DIR)/apps
	endif
else
	ROOT_PATH=$(MVIMPACT_ACQUIRE_SOURCE_DIR)/apps
endif

#-------------------------------------------
BINARY_NAME=IPConfigure
MODULE_NAME=IPConfigureFrame

#-------------------------------------------
OOBJ =						\
	AssignIPDlg.o			\
	CommonGUIFunctions.o	\
	CustomValidators.o		\
	DeviceListCtrl.o		\
	SetupUnicastDlg.o

#-------------------------------------------
vpath %.cpp ..:../../Common:../linux

#-----------------------------------------
LOC_LIB_PATH=$(WORK)/lib/$(TARGET)

#-------------------------------------------
# 'WX_CONF_TOOL' will be set in Makefile.samp.inc
#-------------------------------------------
WXRELEASE=$(shell $(WX_CONF_TOOL) --release)
WXLIBFLAGS=$(shell $(WX_CONF_TOOL) --libs)
WXCXXFLAGS=$(shell $(WX_CONF_TOOL) --cxxflags)

#-------------------------------------------
USR_INCLS =				\

#-------------------------------------------
USR_LIBS =				\
	$(ADD_LIBS)

#-------------------------------------------
LDOPT_1 =				\
	$(WXLIBFLAGS)			\

#-------------------------------------------
# Local typedefs warning since gcc version 4.8 (wxWidgets code)
GCC_MAJOR := $(shell g++ -dumpversion 2>&1 | cut -d'.' -f1)
GCC_MINOR := $(shell g++ -dumpversion 2>&1 | cut -d'.' -f2)
NOLOCALTYPEDEFWARNING := $(shell if [ $(GCC_MAJOR) -ge 4 ] && [ $(GCC_MINOR) -ge 8 ]; then		\
						 echo "-Wno-unused-local-typedefs";			\
						 else										\
						 echo "";									\
						 fi )
#-------------------------------------------
CPPFLAGS_1 = $(NOLOCALTYPEDEFWARNING) \
	-pedantic \
	-Wno-long-long \
	-Wno-variadic-macros \
	-Wno-strict-aliasing \
	-Wno-cast-function-type \
	-Wno-deprecated-copy \
	-Wno-ignored-qualifiers \
	$(WXCXXFLAGS)

#-------------------------------------------
include $(ROOT_PATH)/Makefile.samp.inc
